import json
import string

import requests
import html

from translate_test import settings


def sogou_translate(text):
    if type(text) is list:
        text = [sogou_translate(i).strip(string.punctuation) for i in text]
        return text
    data = {'from_lang': 'zh-CHS', 'to_lang': 'en',
            'trans_frag': [{'text': text}]}
    headers = {'Content-Type': 'application/json'}
    response = requests.post(
        url=settings.TRANSLATE_URL, headers=headers, data=json.dumps(data))
    json_response = response.json()
    if json_response.get('status', 0) < 0:
        raise Exception(json_response.get('error_string'))
    text = html.unescape(json_response['trans_result'][0]['trans_text'])
    return text.strip(string.punctuation)


if __name__ == '__main__':
    sogou_translate.run()



import mongoengine

from holoread_translate.model.base_model import BaseModel


class Pages(BaseModel, mongoengine.Document):
    title = mongoengine.StringField(required=True)
    en_title = mongoengine.StringField(required=True)
    url = mongoengine.URLField(required=True, unique=True)
    source = mongoengine.StringField(required=True)

    meta = {'indexes': ['url', 'source']}

    def api_base_response(self):
        return {
            'title': self.title,
            'en_title': self.en_title,
            'url': self.url,
            'source': self.source
        }

    def api_response(self):
        return self.api_base_response()




from setuptools import setup, find_packages

setup(
    name='translate-test',
    version='0.1.0',
    description='sogou',
    classifiers=[
        'Programming Language :: Python',
        'Intended Audience :: Developers'
    ],
    author='chen',
    url='https://github.com/mydu27/deemo',
    author_email='chenjiageng@geekpark.net',
    packages=find_packages('requests'),
    include_package_data=False,
    zip_safe=True
)



import mongoengine

from holoread_translate.model.base_model import BaseModel


class RankDetail(BaseModel, mongoengine.Document):
    company = mongoengine.ObjectIdField(required=True)
    time_range = mongoengine.StringField(required=True)
    pages = mongoengine.ListField(required=True, default=[])
    news_count = mongoengine.IntField(required=False, default=0)
    financing_pages = mongoengine.ListField(required=False, default=[])
    product_pages = mongoengine.ListField(required=False, default=[])
    sentiment_pages = mongoengine.ListField(required=False, default=[])
    topic = mongoengine.ListField(required=False, default=[])
    negative_topics = mongoengine.ListField(required=False, default=[])

    meta = {'indexes': ['name', 'official_name',
                        'industry_tag', 'series_history']}

    def api_base_response(self):
        return {
            'pages': self.pages,
            'news_count': self.news_count,
            'financing_pages': self.financing_pages,
            'product_pages': self.product_pages,
            'sentiment_pages': self.sentiment_pages,
            'topic': self.topic,
            'negative_topics': self.negative_topics
        }

    def api_response(self):
        return self.api_base_response()
